<?php
// Admin beállítások kezelése

// Biztonsági ellenőrzés
if (!defined('ABSPATH')) {
    exit; // Közvetlen hozzáférés megakadályozása
}

function hirlevel_feliratkozas_admin_menu() {
    add_options_page(
        'Hírlevél Beállítások',
        'Hírlevél Feliratkozás',
        'manage_options',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_options_page'
    );
}
add_action('admin_menu', 'hirlevel_feliratkozas_admin_menu');

function hirlevel_feliratkozas_options_page() {
    ?>
    <div class="wrap">
        <h1>Hírlevél Feliratkozás Beállítások</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('hirlevel_feliratkozas_options');
            do_settings_sections('hirlevel-feliratkozas');
            submit_button();
            ?>
        </form>
        
        <div class="hirlevel-usage-info">
            <h2>Használati útmutató</h2>
            <p>A hírlevél feliratkozási űrlap beillesztéséhez használd a következő shortcode-ot: <code>[hirlevel_feliratkozas]</code></p>
            <p>A feliratkozási űrlap automatikusan meg fog jelenni popup ablakként a látogatók számára 10 másodperccel az oldal betöltése után, hacsak nem iratkoztak fel korábban, vagy zárták be az űrlapot.</p>
            <p><strong>API Végpont:</strong> <?php echo esc_html(HIRLEVEL_API_ENDPOINT); ?></p>
        </div>
        
        <div class="hirlevel-preview">
            <h2>Előnézet</h2>
            <p>Így fog kinézni a feliratkozási űrlap a jelenlegi beállításokkal:</p>
            <div class="hirlevel-preview-container">
                <?php include plugin_dir_path(dirname(__FILE__)) . 'templates/form-template.php'; ?>
            </div>
            <style>
                .hirlevel-preview-container {
                    max-width: 100%;
                    overflow: auto;
                    padding: 20px;
                    background: #f0f0f0;
                    border: 1px solid #ccc;
                    margin-top: 15px;
                }
                
                /* Elrejtjük a létező id-ket az előnézetben, hogy ne ütközzön a JavaScript kóddal */
                .hirlevel-preview-container #newsletter-email,
                .hirlevel-preview-container #newsletter-terms,
                .hirlevel-preview-container #newsletter-submit {
                    pointer-events: none;
                }
            </style>
        </div>
    </div>
    <?php
}

function hirlevel_feliratkozas_register_settings() {
    // API beállítások
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_api_key');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_api_domain');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_username');
    
    // Stílus beállítások
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_button_color');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_text_color');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_background_color');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_form_width');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_border_radius');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_custom_css');
    
    // Szöveg beállítások
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_form_title');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_form_subtitle');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_email_label');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_terms_text');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_privacy_link');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_button_text');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_privacy_note');
    register_setting('hirlevel_feliratkozas_options', 'hirlevel_feliratkozas_success_message');
    
    // API beállítások szekció
    add_settings_section(
        'hirlevel_feliratkozas_section',
        'API Beállítások',
        'hirlevel_feliratkozas_section_callback',
        'hirlevel-feliratkozas'
    );
    
    // Stílus beállítások szekció
    add_settings_section(
        'hirlevel_feliratkozas_style_section',
        'Megjelenés testreszabása',
        'hirlevel_feliratkozas_style_section_callback',
        'hirlevel-feliratkozas'
    );
    
    // Szöveg beállítások szekció
    add_settings_section(
        'hirlevel_feliratkozas_text_section',
        'Szövegek testreszabása',
        'hirlevel_feliratkozas_text_section_callback',
        'hirlevel-feliratkozas'
    );
    
    // API beállítások mezők
    add_settings_field(
        'hirlevel_feliratkozas_api_key',
        'API Kulcs',
        'hirlevel_feliratkozas_api_key_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_username',
        'Felhasználónév',
        'hirlevel_feliratkozas_username_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_api_domain',
        'Domain',
        'hirlevel_feliratkozas_api_domain_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_section'
    );
    
    // Stílus beállítások mezők
    add_settings_field(
        'hirlevel_feliratkozas_button_color',
        'Gomb színe',
        'hirlevel_feliratkozas_button_color_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_style_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_text_color',
        'Szöveg színe',
        'hirlevel_feliratkozas_text_color_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_style_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_background_color',
        'Háttérszín',
        'hirlevel_feliratkozas_background_color_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_style_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_form_width',
        'Űrlap szélessége',
        'hirlevel_feliratkozas_form_width_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_style_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_border_radius',
        'Sarkok lekerekítése',
        'hirlevel_feliratkozas_border_radius_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_style_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_custom_css',
        'Egyéni CSS',
        'hirlevel_feliratkozas_custom_css_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_style_section'
    );
    
    // Szöveg beállítások mezők
    add_settings_field(
        'hirlevel_feliratkozas_form_title',
        'Űrlap címe',
        'hirlevel_feliratkozas_form_title_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_form_subtitle',
        'Űrlap alcíme',
        'hirlevel_feliratkozas_form_subtitle_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_email_label',
        'Email mező címke',
        'hirlevel_feliratkozas_email_label_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_terms_text',
        'Adatkezelési nyilatkozat szövege',
        'hirlevel_feliratkozas_terms_text_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_privacy_link',
        'Adatkezelési tájékoztató linkje',
        'hirlevel_feliratkozas_privacy_link_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_button_text',
        'Gomb szövege',
        'hirlevel_feliratkozas_button_text_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_privacy_note',
        'Adatvédelmi megjegyzés',
        'hirlevel_feliratkozas_privacy_note_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
    
    add_settings_field(
        'hirlevel_feliratkozas_success_message',
        'Sikeres feliratkozás üzenet',
        'hirlevel_feliratkozas_success_message_callback',
        'hirlevel-feliratkozas',
        'hirlevel_feliratkozas_text_section'
    );
}
add_action('admin_init', 'hirlevel_feliratkozas_register_settings');

function hirlevel_feliratkozas_section_callback() {
    echo '<p>Add meg az API beállításokat a hírlevél feliratkozáshoz.</p>';
    echo '<p><strong>API Végpont:</strong> ' . esc_html(HIRLEVEL_API_ENDPOINT) . '</p>';
}

function hirlevel_feliratkozas_style_section_callback() {
    echo '<p>A hírlevél feliratkozási űrlap megjelenésének testreszabása.</p>';
}

function hirlevel_feliratkozas_text_section_callback() {
    echo '<p>A hírlevél feliratkozási űrlap szövegeinek testreszabása.</p>';
}

// API beállítások callbackek
function hirlevel_feliratkozas_api_key_callback() {
    $api_key = get_option('hirlevel_feliratkozas_api_key', '');
    echo '<input type="text" name="hirlevel_feliratkozas_api_key" value="' . esc_attr($api_key) . '" class="regular-text" required>';
    echo '<p class="description">Az API kulcs, amit a feliratkozás API-hoz kaptál.</p>';
}

function hirlevel_feliratkozas_username_callback() {
    $username = get_option('hirlevel_feliratkozas_username', '');
    echo '<input type="text" name="hirlevel_feliratkozas_username" value="' . esc_attr($username) . '" class="regular-text" required>';
    echo '<p class="description">A felhasználóneved, amivel azonosítják a feliratkozás forrását.</p>';
}

function hirlevel_feliratkozas_api_domain_callback() {
    $domain = get_option('hirlevel_feliratkozas_api_domain', site_url());
    echo '<input type="text" name="hirlevel_feliratkozas_api_domain" value="' . esc_attr($domain) . '" class="regular-text" required>';
    echo '<p class="description">A domain, amit a kérésekben küldeni szeretnél.</p>';
}

// Stílus beállítások callbackek
function hirlevel_feliratkozas_button_color_callback() {
    $button_color = get_option('hirlevel_feliratkozas_button_color', '#403317');
    echo '<input type="text" name="hirlevel_feliratkozas_button_color" value="' . esc_attr($button_color) . '" class="color-picker">';
    echo '<p class="description">A feliratkozás gomb háttérszíne.</p>';
}

function hirlevel_feliratkozas_text_color_callback() {
    $text_color = get_option('hirlevel_feliratkozas_text_color', '#403317');
    echo '<input type="text" name="hirlevel_feliratkozas_text_color" value="' . esc_attr($text_color) . '" class="color-picker">';
    echo '<p class="description">A szövegek színe.</p>';
}

function hirlevel_feliratkozas_background_color_callback() {
    $background_color = get_option('hirlevel_feliratkozas_background_color', '#fbfaf4');
    echo '<input type="text" name="hirlevel_feliratkozas_background_color" value="' . esc_attr($background_color) . '" class="color-picker">';
    echo '<p class="description">Az űrlap háttérszíne.</p>';
}

function hirlevel_feliratkozas_form_width_callback() {
    $form_width = get_option('hirlevel_feliratkozas_form_width', '500');
    echo '<input type="number" name="hirlevel_feliratkozas_form_width" value="' . esc_attr($form_width) . '" min="200" max="1200"> px';
    echo '<p class="description">Az űrlap maximális szélessége pixelben.</p>';
}

function hirlevel_feliratkozas_border_radius_callback() {
    $border_radius = get_option('hirlevel_feliratkozas_border_radius', '0');
    echo '<input type="number" name="hirlevel_feliratkozas_border_radius" value="' . esc_attr($border_radius) . '" min="0" max="50"> px';
    echo '<p class="description">Az űrlap sarkainak lekerekítése.</p>';
}

function hirlevel_feliratkozas_custom_css_callback() {
    $custom_css = get_option('hirlevel_feliratkozas_custom_css', '');
    echo '<textarea name="hirlevel_feliratkozas_custom_css" rows="8" cols="50" class="large-text code">' . esc_textarea($custom_css) . '</textarea>';
    echo '<p class="description">Itt adhatsz meg egyéni CSS kódot az űrlap további testreszabásához.</p>';
}

// Szöveg beállítások callbackek
function hirlevel_feliratkozas_form_title_callback() {
    $form_title = get_option('hirlevel_feliratkozas_form_title', 'Iratkozz fel hírlevelünkre');
    echo '<input type="text" name="hirlevel_feliratkozas_form_title" value="' . esc_attr($form_title) . '" class="regular-text">';
}

function hirlevel_feliratkozas_form_subtitle_callback() {
    $form_subtitle = get_option('hirlevel_feliratkozas_form_subtitle', 'Értesülj az új cikkekről és exkluzív tartalmakról');
    echo '<input type="text" name="hirlevel_feliratkozas_form_subtitle" value="' . esc_attr($form_subtitle) . '" class="regular-text">';
}

function hirlevel_feliratkozas_email_label_callback() {
    $email_label = get_option('hirlevel_feliratkozas_email_label', 'Email cím');
    echo '<input type="text" name="hirlevel_feliratkozas_email_label" value="' . esc_attr($email_label) . '" class="regular-text">';
}

function hirlevel_feliratkozas_terms_text_callback() {
    $terms_text = get_option('hirlevel_feliratkozas_terms_text', 'Elfogadom az adatkezelési tájékoztatót, és hozzájárulok a személyes adataim kezeléséhez.');
    echo '<textarea name="hirlevel_feliratkozas_terms_text" rows="3" cols="50" class="large-text">' . esc_textarea($terms_text) . '</textarea>';
    echo '<p class="description">Az "adatkezelési tájékoztatót" szövegrészre automatikusan link kerül, ami az alább megadott URL-re mutat.</p>';
}

function hirlevel_feliratkozas_privacy_link_callback() {
    $privacy_link = get_option('hirlevel_feliratkozas_privacy_link', site_url('/adatkezeles'));
    echo '<input type="url" name="hirlevel_feliratkozas_privacy_link" value="' . esc_attr($privacy_link) . '" class="regular-text">';
    echo '<p class="description">Az adatkezelési tájékoztató oldal teljes URL-je.</p>';
}

function hirlevel_feliratkozas_button_text_callback() {
    $button_text = get_option('hirlevel_feliratkozas_button_text', 'Feliratkozás');
    echo '<input type="text" name="hirlevel_feliratkozas_button_text" value="' . esc_attr($button_text) . '" class="regular-text">';
}

function hirlevel_feliratkozas_privacy_note_callback() {
    $privacy_note = get_option('hirlevel_feliratkozas_privacy_note', 'Tiszteletben tartjuk a magánéletedet. Bármikor leiratkozhatsz.');
    echo '<input type="text" name="hirlevel_feliratkozas_privacy_note" value="' . esc_attr($privacy_note) . '" class="regular-text">';
}

function hirlevel_feliratkozas_success_message_callback() {
    $success_message = get_option('hirlevel_feliratkozas_success_message', 'Sikeresen feliratkoztál!');
    echo '<input type="text" name="hirlevel_feliratkozas_success_message" value="' . esc_attr($success_message) . '" class="regular-text">';
}